package de.intevation.gnv.state;

import de.intevation.artifacts.CallContext;

import de.intevation.gnv.state.exception.StateException;

import java.io.Serializable;

import java.util.Collection;
import java.util.Map;

import org.w3c.dom.Document;
import org.w3c.dom.Node;

/**
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 * @author <a href="mailto:sascha.teichmann@intevation.de">Sascha L. Teichmann</a>
 */
public interface State extends Serializable {

    public void setup(Node configuration);

    public String getID();

    public String getDescription();

    public void describe(
        Document    document,
        Node        rootNode,
        CallContext context,
        String      uuid
    );

    public Document feed(
        CallContext context, Collection<InputData> inputData, String uuid)
    throws StateException;

    public void setParent(State state);

    public State getParent();

    public Collection<InputValue> getRequiredInputValues();

    public Map<String, InputData> inputData();

    public void putInputData(Collection<InputData> inputData, String uuid)
    throws StateException;

    public Collection<InputData> getInputData() throws StateException;

    public void advance(String uuid, CallContext context)
    throws StateException;

    public void initialize(String uuid, CallContext context)
    throws StateException;

    public void reset(String uuid);

    public void endOfLife(Object globalContext);

    public void setPreSettings(Map<String,InputData> preSettings);

    public Map<String,InputData> getPreSettings();

    public void cleanup(Object context);
}
